@@ -82,6 +82,32 @@ impl Client {
             //last_event: EventResponse::default(),
         }
     }
+    pub fn set_auth_token(&mut self, auth_token: String) {
+        let should_req_well_known = match self.host.split(":").last().unwrap().parse::<usize>() {
+            Ok(port) => {
+                if port != 443 {
+                    false
+                } else {
+                    true
+                }
+            },
+            Err(_) => {
+                true
+            }
+        };
+        if should_req_well_known {
+            if let Ok(z) = ureq::get(&format!("{}/.well-known/matrix/client", self.host.clone())).call() {
+                //panic!("{}", z.into_string().unwrap());
+                
+                let resp: Value = z.into_json().unwrap();
+                let base_url: String = resp["m.homeserver"]["base_url"].as_str().unwrap().to_string();
+                self.host = base_url.trim_end_matches("/").to_string();
+                
+                //self.me = UserId::try_from(format!("@{}:{}", self.me.localpart(), self.host.clone().split_once("://").unwrap().1).as_str()).unwrap();
+            }
+        }
+        self.data.auth_token = auth_token;
+    }
     pub fn login(&mut self, password: String) {
         let should_req_well_known = match self.host.split(":").last().unwrap().parse::<usize>() {
             Ok(port) => {
